==> victoria-metrics-1.104.0.tar.gz: VictoriaMetrics-1.104.0/docs/victoriametrics-cloud/support.md <==
---
weight: 12
title: VictoriaMetrics Cloud Support
menu:
  docs:
    parent: "cloud"
    weight: 12
    name: Support
---
## Basic Support
All offerings include basic support, where we maintain the health of your deployments, perform system upgrades, and proactively contact customers if issues arise.

All changes are logged and visible in the [Audit log](https://cloud.victoriametrics.com/audit).

## How to Reach Support
To contact support, use the [Contact Support](https://cloud.victoriametrics.com/contact_support) button in the Cloud UI.

We categorize support requests into three types:
- Issues
- Feature Requests
- General Questions

### Common reasons to reach out:
- Troubleshoot deployment, metrics reading, or writing issues.
- Report potential bugs in VictoriaMetrics Cloud.
- Increase the quota (default: 5 single nodes, 2 clusters). If more is needed, submit a support ticket.
- Request a higher-tier plan or a custom tier.
- Provide feedback.
- General questions about the functionality.

## Status Page
Check the status of VictoriaMetrics Cloud [here](https://status.victoriametrics.com/).

## Maintenance
Maintenance of your deployments occurs during the maintenance window, which you can set in your deployment settings.  
VictoriaMetrics handles the infrastructure and deployment maintenance.

For general updates, refer to the [status page](#status-page).

## Enhanced Support and Guidance
For enhanced support or guidance on VictoriaMetrics and observability, [contact us](https://victoriametrics.com/contact-us/) and see our [plans and features](https://victoriametrics.com/plans-features/)

## Useful Links
- [Service Level Agreement](https://victoriametrics.com/legal/cloud/terms-of-service/#service-levels)
- [Terms of Use](https://victoriametrics.com/legal/cloud/terms-of-service/)

==> victoria-metrics-1.108.1.tar.gz: VictoriaMetrics-1.108.1/docs/victoriametrics-cloud/support.md <==
---
weight: 12
title: VictoriaMetrics Cloud Support
menu:
  docs:
    parent: "cloud"
    weight: 12
    name: Support
---
## Basic Support
All offerings include [Silver level](https://victoriametrics.com/plans-features/) of support, where we maintain the health of your deployments, perform system upgrades, and proactively contact customers if issues arise.

All changes are logged and visible in the [Audit log](https://console.victoriametrics.cloud/audit ). For more details, check the [documentation](https://docs.victoriametrics.com/victoriametrics-cloud/audit-logs/) 

## How to Reach Support
To contact support, use the [Contact Support](https://console.victoriametrics.cloud/contact_support) button in the Cloud UI.

We categorize support requests into three types:
- Issues
- Feature Requests
- General Questions

### Common reasons to reach out:
- Troubleshoot deployment, metrics reading, or writing issues.
- Report potential bugs in VictoriaMetrics Cloud.
- Increase the quota (default: 5 single nodes, 2 clusters). If more is needed, submit a support ticket.
- Request a higher-tier plan or a custom tier.
- Provide feedback.
- General questions about the functionality.

## Status Page
Check the status of VictoriaMetrics Cloud [here](https://status.victoriametrics.com/).

## Maintenance
Maintenance of your deployments occurs during the maintenance window, which you can set in your deployment settings.  
VictoriaMetrics handles the infrastructure and deployment maintenance.

For general updates, refer to the [status page](#status-page).

## Enhanced Support and Guidance
For enhanced support or guidance on VictoriaMetrics and observability, [contact us](https://victoriametrics.com/contact-us/) and see our [plans and features](https://victoriametrics.com/plans-features/)

## Useful Links
- [Service Level Agreement](https://victoriametrics.com/legal/cloud/terms-of-service/#service-levels)
- [Terms of Use](https://victoriametrics.com/legal/cloud/terms-of-service/)
